@@ -43,6 +43,7 @@
 #import	<Foundation/NSAutoreleasePool.h>
 #import	<Foundation/NSBundle.h>
 #import	<Foundation/NSByteOrder.h>
+#import	<Foundation/NSCache.h>
 #import	<Foundation/NSCalendarDate.h>
 #import	<Foundation/NSCharacterSet.h>
 #import	<Foundation/NSClassDescription.h>
@@ -65,6 +66,7 @@
 #import	<Foundation/NSFileHandle.h>
 #import	<Foundation/NSFileManager.h>
 #import	<Foundation/NSFormatter.h>
+#import	<Foundation/NSGarbageCollector.h>
 #import	<Foundation/NSGeometry.h>
 #import	<Foundation/NSHashTable.h>
 #import	<Foundation/NSHost.h>
@@ -75,6 +77,7 @@
 #import	<Foundation/NSInvocation.h>
 #import	<Foundation/NSKeyedArchiver.h>
 #import	<Foundation/NSKeyValueCoding.h>
+#import	<Foundation/NSKeyValueObserving.h>
 #import	<Foundation/NSLock.h>
 #import	<Foundation/NSMapTable.h>
 #import	<Foundation/NSMethodSignature.h>
@@ -83,7 +86,10 @@
 #import	<Foundation/NSNetServices.h>
 #import	<Foundation/NSNull.h>
 #import	<Foundation/NSNumberFormatter.h>
+#import	<Foundation/NSOperation.h>
 #import	<Foundation/NSPathUtilities.h>
+#import	<Foundation/NSPointerArray.h>
+#import	<Foundation/NSPointerFunctions.h>
 #import	<Foundation/NSPortCoder.h>
 #import	<Foundation/NSPortMessage.h>
 #import	<Foundation/NSPortNameServer.h>
@@ -121,6 +127,12 @@
 #import	<Foundation/NSUserDefaults.h>
 #import	<Foundation/NSValue.h>
 #import	<Foundation/NSValueTransformer.h>
+#import <Foundation/NSXMLDocument.h>
+#import <Foundation/NSXMLDTD.h>
+#import <Foundation/NSXMLDTDNode.h>
+#import <Foundation/NSXMLElement.h>
+#import <Foundation/NSXMLNode.h>
+#import <Foundation/NSXMLNodeOptions.h>
 #import	<Foundation/NSXMLParser.h>
 #import	<Foundation/NSZone.h>
 
