@@ -22,7 +22,6 @@
    Boston, MA 02111 USA.
 
    AutogsdocSource: NSObject.m
-   AutogsdocSource: Additions/GSCategories.m
    */ 
 
 #ifndef __NSObject_h_GNUSTEP_BASE_INCLUDE
@@ -68,7 +67,7 @@ extern "C" {
 - (BOOL) isKindOfClass: (Class)aClass;	/** See [NSObject-isKindOfClass:] */
 - (BOOL) isMemberOfClass: (Class)aClass;/** See [NSObject-isMemberOfClass:] */
 - (BOOL) isProxy;			/** See [NSObject-isProxy] */
-- (unsigned) hash;			/** See [NSObject-hash] */
+- (NSUInteger) hash;			/** See [NSObject-hash] */
 - (id) self;				/** See [NSObject-self] */
 - (id) performSelector: (SEL)aSelector;	/** See [NSObject-performSelector:] */
 /** See [NSObject-performSelector:withObject:] */
@@ -85,7 +84,7 @@ extern "C" {
 - (id) retain;				/** See [NSObject-retain] */
 - (id) autorelease			/** See [NSObject-autorelease] */;
 - (oneway void) release;		/** See [NSObject-release] */
-- (unsigned) retainCount;		/** See [NSObject-retainCount] */
+- (NSUInteger) retainCount;		/** See [NSObject-retainCount] */
 - (NSZone*) zone;			/** See [NSObject-zone] */
 - (NSString*) description;		/** See [NSObject-description] */
 @end
@@ -171,10 +170,13 @@ extern "C" {
   Class isa;
 }
 
-#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
-#if	GS_WITH_GC
-+ (BOOL) requiresTypedMemory;
-#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+/** On a system which performs garbage collection, you should implement
+ * this method to execute code when the receiver is collected.<br />
+ * You must not call this method yourself (except when a subclass
+ * calls the superclass method within its own implementation).
+ */
+- (void) finalize;
 #endif
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
@@ -185,6 +187,52 @@ extern "C" {
 + (id) alloc;
 + (Class) class;
 + (NSString*) description;
+
+/**
+ * This method is automatically invoked on any class which implements it
+ * when the class is loaded into the runtime.<br />
+ * It is also invoked on any category where the method is implemented
+ * when that category is loaded into the runtime.<br />
+ * The +load method is called directly by the runtime and you should never
+ * send a +load message to a class yourself.<br />
+ * This method is called <em>before</em> the +initialize message is sent
+ * to the class, so you cannot depend on class initialisation having been
+ * performed, or upon other classes existing (apart from superclasses of
+ * the receiver, since +load is called on superclasses before it is called
+ * on their subclasses).<br />
+ * As a gross generalisation, it is safe to use C code, including
+ * most ObjectiveC runtime functions within +load, but attempting to send
+ * messages to ObjectiveC objects is likely to fail.<br />
+ * In GNUstep, this method is implemented for NSObject to perform some
+ * initialisation for the base library.<br />
+ * If you implement +load for a class, don't call [super load] in your
+ * implementation.
+ */
++ (void) load;
+
+/**
+ * This message is automatically sent to a class by the runtime.  It is
+ * sent once for each class, just before the class is used for the first
+ * time (excluding any automatic call to +load by the runtime).<br />
+ * The message is sent in a thread-safe manner ... other threads may not
+ * call methods of the class until +initialize has finished executing.<br />
+ * If the class has a superclass, its implementation of +initialize is
+ * called first.<br />
+ * If the class does not implement +initialize then the implementation
+ * in the closest superclass may be called.  This means that +initialize may
+ * be called more than once, and the recommended way to handle this by
+ * using the
+ * <code>
+ * if (self == [classname class])
+ * </code>
+ * conditional to check whether the method is being called for a subclass.<br />
+ * You should never call +initialize yourself ... let the runtime do it.<br />
+ * You can implement +initialize in your own class if you need to.
+ * NSObject's implementation handles essential root object and base
+ * library initialization.<br />
+ * It should be safe to call [super initialize] in your implementation
+ * of +initialize.
+ */
 + (void) initialize;
 + (IMP) instanceMethodForSelector: (SEL)aSelector;
 + (NSMethodSignature*) instanceMethodSignatureForSelector: (SEL)aSelector;
@@ -192,9 +240,9 @@ extern "C" {
 + (BOOL) isSubclassOfClass: (Class)aClass;
 + (id) new;
 + (void) poseAsClass: (Class)aClassObject;
-+ (id) setVersion: (int)aVersion;
++ (id) setVersion: (NSInteger)aVersion;
 + (Class) superclass;
-+ (int) version;
++ (NSInteger) version;
 
 - (id) autorelease;
 - (id) awakeAfterUsingCoder: (NSCoder*)aDecoder;
@@ -207,7 +255,7 @@ extern "C" {
 - (NSString*) description;
 - (void) doesNotRecognizeSelector: (SEL)aSelector;
 - (void) forwardInvocation: (NSInvocation*)anInvocation;
-- (unsigned) hash;
+- (NSUInteger) hash;
 - (id) init;
 - (BOOL) isEqual: anObject;
 - (BOOL) isKindOfClass: (Class)aClass;
@@ -227,10 +275,65 @@ extern "C" {
 - (id) replacementObjectForCoder: (NSCoder*)anEncoder;
 - (BOOL) respondsToSelector: (SEL)aSelector;
 - (id) retain;
-- (unsigned) retainCount;
+- (NSUInteger) retainCount;
 - (id) self;
 - (Class) superclass;
 - (NSZone*) zone;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+/**
+ * This method will be called when attempting to send a message a class that
+ * does not understand it.  The class may install a new method for the given
+ * selector and return YES, otherwise it should return NO.
+ *
+ * Note: This method is only reliable when using the GNUstep runtime.  If you
+ * require compatibility with the GCC runtime, you must also implement
+ * -forwardInvocation: with equivalent semantics.  This will be considerably
+ *  slower, but more portable.
+ */
++ (BOOL) resolveClassMethod: (SEL)name;
+
+/**
+ * This method will be called when attempting to send a message an instance
+ * that does not understand it.  The class may install a new method for the
+ * given selector and return YES, otherwise it should return NO.
+ *
+ * Note: This method is only reliable when using the GNUstep runtime.  If you
+ * require compatibility with the GCC runtime, you must also implement
+ * -forwardInvocation: with equivalent semantics.  This will be considerably
+ *  slower, but more portable.
+ */
++ (BOOL) resolveInstanceMethod: (SEL)name;
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+/**
+ * Returns an auto-accessing proxy for the given object.  This proxy sends a
+ * -beginContentAccess message to the receiver when it is created and an
+ * -endContentAccess message when it is destroyed.  This prevents an object
+ * that implements the NSDiscardableContent protocol from having its contents
+ * discarded for as long as the proxy exists.  
+ *
+ * On systems using the GNUstep runtime, messages send to the proxy will be
+ * slightly slower than direct messages.  With the GCC runtime, they will be
+ * approximately two orders of magnitude slower.  The GNUstep runtime,
+ * therefore, is strongly recommended for code calling this method.
+ */
+- (id) autoContentAccessingProxy;
+
+/**
+ * If an object does not understand a message, it may delegate it to another
+ * object.  Returning nil indicates that forwarding should not take place.  The
+ * default implementation of this returns nil, but care should be taken when
+ * subclassing NSObject subclasses and overriding this method that
+ * the superclass implementation is called if returning nil.
+ *
+ * Note: This method is only reliable when using the GNUstep runtime and code
+ * compiled with clang.  If you require compatibility with GCC and the GCC
+ * runtime, you must also implement -forwardInvocation: with equivalent
+ * semantics.  This will be considerably slower, but more portable.
+ */
+- (id) forwardingTargetForSelector: (SEL)aSelector;
+
+#endif
 @end
 
 /**
@@ -240,15 +343,15 @@ extern "C" {
  * instance variables of the object.<br />
  * This function is used by the [NSObject+allocWithZone:] method.
  */
-GS_EXPORT NSObject *
-NSAllocateObject(Class aClass, unsigned extraBytes, NSZone *zone);
+GS_EXPORT id
+NSAllocateObject(Class aClass, NSUInteger extraBytes, NSZone *zone);
 
 /**
  * Used to release the memory used by an object.<br />
  * This function is used by the [NSObject-dealloc] method.
  */
 GS_EXPORT void
-NSDeallocateObject(NSObject *anObject);
+NSDeallocateObject(id anObject);
 
 /**
  * Used to copy anObject.  This makes a bitwise copy of anObject to
@@ -259,7 +362,7 @@ NSDeallocateObject(NSObject *anObject);
  * [(NSCopying)-copyWithZone:] method.
  */
 GS_EXPORT NSObject *
-NSCopyObject(NSObject *anObject, unsigned extraBytes, NSZone *zone);
+NSCopyObject(NSObject *anObject, NSUInteger extraBytes, NSZone *zone);
 
 /**
  * Returns a flag to indicate whether anObject should be retained or
@@ -273,7 +376,7 @@ NSShouldRetainWithZone(NSObject *anObject, NSZone *requestedZone);
 GS_EXPORT BOOL
 NSDecrementExtraRefCountWasZero(id anObject);
 
-GS_EXPORT unsigned
+GS_EXPORT NSUInteger
 NSExtraRefCount(id anObject);
 
 GS_EXPORT void
@@ -307,75 +410,14 @@ GS_EXPORT NSRecursiveLock *gnustep_global_lock;
 
 #if GS_API_VERSION(GS_API_NONE, 011700)
 @interface NSObject (GNUstep)
-- (BOOL) isInstance;
-- (id) makeImmutableCopyOnFail: (BOOL)force;
-- (Class) transmuteClassTo: (Class)aClassObject;
-+ (Class) autoreleaseClass;
-+ (void) setAutoreleaseClass: (Class)aClass;
 + (void) enableDoubleReleaseCheck: (BOOL)enable;
 - (id) read: (TypedStream*)aStream;
 - (id) write: (TypedStream*)aStream;
 @end
 #endif
 
-/**
- * Provides a number of GNUstep-specific methods that are used to aid
- * implementation of the Base library.
- */
-@interface NSObject (GSCategories)
-
-/**
- * Message sent when an implementation wants to explicitly exclude a method
- * (but cannot due to compiler constraint), and wants to make sure it is not
- * called by mistake.  Default implementation raises an exception at runtime.
- */
-- notImplemented:(SEL)aSel;
-
-/**
- * Message sent when an implementation wants to explicitly require a subclass
- * to implement a method (but cannot at compile time since there is no
- * <code>abstract</code> keyword in Objective-C).  Default implementation
- * raises an exception at runtime to alert developer that he/she forgot to
- * override a method.
- */
-- (id) subclassResponsibility: (SEL)aSel;
-
-/**
- * Message sent when an implementation wants to explicitly exclude a method
- * (but cannot due to compiler constraint) and forbid that subclasses
- * implement it.  Default implementation raises an exception at runtime.  If a
- * subclass <em>does</em> implement this method, however, the superclass's
- * implementation will not be called, so this is not a perfect mechanism.
- */
-- (id) shouldNotImplement: (SEL)aSel;
-
-/**
-  WARNING: The -compare: method for NSObject is deprecated
-           due to subclasses declaring the same selector with
-           conflicting signatures.
-           Comparison of arbitrary objects is not just meaningless
-           but also dangerous as most concrete implementations
-           expect comparable objects as arguments often accessing
-           instance variables directly.
-           This method will be removed in a future release.
-*/
-- (NSComparisonResult) compare: (id)anObject;
-@end
-
 #endif
 
-/**
- *	Protocol for garbage collection finalization - same as libFoundation
- *	for compatibility.
- */
-@protocol       GCFinalization
-/**
- *  Called before receiver is deallocated by garbage collector.  If you want
- *  to do anything special before [NSObject -dealloc] is called, do it here.
- */
-- (void) gcFinalize;
-@end
-
 #import	<Foundation/NSDate.h>
 /**
  *  Declares some methods for sending messages to self after a fixed delay.
@@ -417,8 +459,48 @@ GS_EXPORT NSRecursiveLock *gnustep_global_lock;
 		 inModes: (NSArray*)modes;
 @end
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+/**
+ * The NSDiscardableContent protocol is used by objects which encapsulate data
+ * which may be discarded if resource constraints are exceeded.  These
+ * constraints are typically, but not always, related memory.  
+ */
+@protocol NSDiscardableContent
+
+/**
+ * This method is called before any access to the object.  It returns YES if
+ * the object's content is still valid.  The caller must call -endContentAccess
+ * once for every call to -beginContentAccess;
+ */
+- (BOOL) beginContentAccess;
+
+/**
+ * Discards the contents of the object if it is not currently being edited.
+ */
+- (void) discardContentIfPossible;
+
+/**
+ * This method indicates that the caller has finished accessing the contents of
+ * the object adopting this protocol.  Every call to -beginContentAccess must
+ * be be paired with a call to this method after the caller has finished
+ * accessing the contents.
+ */
+- (void) endContentAccess;
+
+/**
+ * Returns YES if the contents of the object have been discarded, either via a
+ * call to -discardContentIfPossible while the object is not in use, or by some
+ * implementation dependent mechanism.  
+ */
+- (BOOL) isContentDiscarded;
+@end
+#endif
 #if	defined(__cplusplus)
 }
 #endif
 
+#if     !NO_GNUSTEP && !defined(GNUSTEP_BASE_INTERNAL)
+#import <GNUstepBase/NSObject+GNUstepBase.h>
+#endif
+
 #endif /* __NSObject_h_GNUSTEP_BASE_INCLUDE */
