@@ -27,27 +27,33 @@
 
 #include <stdlib.h>
 #include <stdarg.h>
-#include <GNUstepBase/objc-gnu2next.h>
 
 #if     defined(__WIN32__) || defined(_WIN32) || defined(__MS_WIN32__)
-#ifndef __WIN32__
-#define __WIN32__
-#endif
+#  if	!defined(__WIN32__)
+#    define __WIN32__
+#  endif
 #endif
 
-#ifdef __MINGW32__
-#ifndef __MINGW__
-#define __MINGW__
-#endif
-#ifndef __WIN32__
-#define __WIN32__
-#endif
+#if	defined(__MINGW32__)
+#  if	!defined(__MINGW__)
+#    define __MINGW__
+#  endif
+#  if	!defined(__WIN32__)
+#    define __WIN32__
+#  endif
 #endif
 
 #if defined(__WIN32__)
 #include <w32api.h>
+#ifndef _WIN32_WINNT
 #define _WIN32_WINNT Windows2000
+#endif
+#if	!defined(WINVER)
 #define WINVER Windows2000
+#elif (WINVER < Windows2000)
+#undef	WINVER
+#define WINVER Windows2000
+#endif
 #include <windows.h>
 #define GNUSTEP_BASE_SOCKET_MESSAGE (WM_USER + 1)
 #endif
@@ -95,10 +101,10 @@
 #endif
 
 /* The following group of lines maintained by the gstep-base configure */
-#define GNUSTEP_BASE_VERSION            2.1.0
-#define GNUSTEP_BASE_MAJOR_VERSION      2
+#define GNUSTEP_BASE_VERSION            3.1.1
+#define GNUSTEP_BASE_MAJOR_VERSION      3
 #define GNUSTEP_BASE_MINOR_VERSION      1
-#define GNUSTEP_BASE_SUBMINOR_VERSION   0
+#define GNUSTEP_BASE_SUBMINOR_VERSION   1
 #define GNUSTEP_BASE_GCC_VERSION        2.9.5
 
 #define OBJC_MALLOC(VAR, TYPE, NUM) \
